/**
 *
 * @author Zhuplev Anton
 */
import java.io.*;
import java.util.*;



public class sol_zhuplev implements Runnable {


  private String input = "input.txt";
  private String output = "output.txt";
  private Scanner in = null;
  private PrintWriter out = null;


  public sol_zhuplev() {
    try {
      in = new Scanner(new File(input));
      out = new PrintWriter(new File(output));
    } catch (Exception exept) {
      exept.printStackTrace();
      System.exit(1);
    }
  }


  public static void main(String[] args) {
    Locale.setDefault(Locale.US);
    new Thread(new sol_zhuplev()).start();
  }


  public void run() {
    try {
      solve();
    } catch (Exception exept) {
      exept.printStackTrace();
      System.exit(1);
    } finally {
      in.close();
      out.close();
    }
  }


  private void myAssert(boolean expr, String message) {
    if (!expr) {
      throw new Error("Assertion failure!!! " + message);
    }
  }


  boolean isPalindrome(String s) {
    boolean result = true;
    for (int i = 0; i < s.length() / 2; i++) {
      result &= s.charAt(i) == s.charAt(s.length() - 1 - i);
    }
    return result;
  }


  int[] getSegments(String s, int k) {
    if (s.length() % k != 0) {
      return null;
    } else {
      int[] result = new int[k];
      int len = s.length() / k;
      for (int i = 0; i < result.length; i++) {
        result[i] = new Integer(s.substring(i*len, (i+1)*len));
      }
      return result;
    }
  }


  boolean isSegmentsDependence(String s) {
    boolean result = false;
    int[] segments;
    for (int sc = 2; sc <= 8; sc++) {
      segments = getSegments(s, sc);
      if (segments != null) {
        boolean ok = true;
        for (int j = 1; j < sc; j++) {
          ok &= segments[j] == segments[j-1];
        }
        result |= ok;
      }
    }
    return result;
  }


  boolean success(String s) {
    return isPalindrome(s) || isSegmentsDependence(s);
  }


  @SuppressWarnings("unchecked")
  private void solve() {
    int d = in.nextInt();
    int m = in.nextInt();
    int y = in.nextInt();

    myAssert(1 <= m && m <= 12, "Month is out of bounds");
    myAssert(1600 <= y && y <= 9999, "Year is out of bounds");
    // int rb = (m != 2 ? 30 + (m % 2)^(m > 7) : 28 + !(y % 400) || !(y % 4) && (y % 25));
    int rb;
    if (m != 2) {
      rb = 30;
      if ((m % 2 == 0) && (m > 7) || (m % 2 != 0) && (m <= 7)) {
        rb++;
      }
    } else {
      rb = (y % 400 == 0) || (y % 4 == 0) && (y % 25 != 0) ? 29 : 28;
    }
    myAssert(1 <= d && d <= rb, "Day is out of bounds");

    GregorianCalendar date = new GregorianCalendar(y, m-1, d);

    do {
      d = date.get(Calendar.DAY_OF_MONTH);
      m = date.get(Calendar.MONTH) + 1;
      y = date.get(Calendar.YEAR);

      boolean ok = false;

      String dayVariants[] = {String.format("%d", d), String.format("%02d", d)};
      String MonthVariants[] = {String.format("%d", m), String.format("%02d", m)};
      String yearVariants[] = {String.format("%02d", y % 100), String.format("%d", y)};

      for (String dd : dayVariants) {
        for (String mm : MonthVariants) {
          for (String yy : yearVariants) {
            String candidate = dd.concat(mm).concat(yy);
            ok |= success(candidate);
          }
        }
      }
      if (ok) {
        break;
      }
      date.add(Calendar.DAY_OF_MONTH, 1);
    } while (true);

    out.format("%d %d %d\n", d, m, y);
  }
}
